Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/netinet6 Add nd6_ prefix to exported functions



details:   https://anonhg.NetBSD.org/src/rev/db94dc897d1d
branches:  trunk
changeset: 349468:db94dc897d1d
user:      ozaki-r <ozaki-r%NetBSD.org@localhost>
date:      Sun Dec 11 07:38:50 2016 +0000

description:
Add nd6_ prefix to exported functions

diffstat:

 sys/netinet6/in6.c     |  14 ++++++------
 sys/netinet6/nd6.c     |  50 ++++++++++++++++++++++----------------------
 sys/netinet6/nd6.h     |  16 +++++++-------
 sys/netinet6/nd6_nbr.c |  14 ++++++------
 sys/netinet6/nd6_rtr.c |  56 +++++++++++++++++++++++++-------------------------
 5 files changed, 75 insertions(+), 75 deletions(-)

diffs (truncated from 551 to 300 lines):

diff -r 730625e73968 -r db94dc897d1d sys/netinet6/nd6.h
--- a/sys/netinet6/nd6.h        Sun Dec 11 07:37:53 2016 +0000
+++ b/sys/netinet6/nd6.h        Sun Dec 11 07:38:50 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: nd6.h,v 1.75 2016/12/11 07:37:53 ozaki-r Exp $ */
+/*     $NetBSD: nd6.h,v 1.76 2016/12/11 07:38:50 ozaki-r Exp $ */
 /*     $KAME: nd6.h,v 1.95 2002/06/08 11:31:06 itojun Exp $    */
 
 /*
@@ -433,13 +433,13 @@
 /* nd6_rtr.c */
 void nd6_rs_input(struct mbuf *, int, int);
 void nd6_ra_input(struct mbuf *, int, int);
-void defrouter_reset(void);
-void defrouter_select(void);
-void defrtrlist_del(struct nd_defrouter *, struct in6_ifextra *);
-void prelist_remove(struct nd_prefix *);
-void pfxlist_onlink_check(void);
-struct nd_defrouter *defrouter_lookup(const struct in6_addr *, struct ifnet *);
-void rt6_flush(struct in6_addr *, struct ifnet *);
+void nd6_defrouter_reset(void);
+void nd6_defrouter_select(void);
+void nd6_defrtrlist_del(struct nd_defrouter *, struct in6_ifextra *);
+void nd6_prelist_remove(struct nd_prefix *);
+void nd6_pfxlist_onlink_check(void);
+struct nd_defrouter *nd6_defrouter_lookup(const struct in6_addr *, struct ifnet *);
+void nd6_rt_flush(struct in6_addr *, struct ifnet *);
 int in6_tmpifadd(const struct in6_ifaddr *, int, int);
 bool nd6_accepts_rtadv(const struct nd_ifinfo *);
 
diff -r 730625e73968 -r db94dc897d1d sys/netinet6/nd6_nbr.c
--- a/sys/netinet6/nd6_nbr.c    Sun Dec 11 07:37:53 2016 +0000
+++ b/sys/netinet6/nd6_nbr.c    Sun Dec 11 07:38:50 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: nd6_nbr.c,v 1.130 2016/11/15 21:17:07 mlelstv Exp $    */
+/*     $NetBSD: nd6_nbr.c,v 1.131 2016/12/11 07:38:50 ozaki-r Exp $    */
 /*     $KAME: nd6_nbr.c,v 1.61 2001/02/10 16:06:14 jinmei Exp $        */
 
 /*
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: nd6_nbr.c,v 1.130 2016/11/15 21:17:07 mlelstv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: nd6_nbr.c,v 1.131 2016/12/11 07:38:50 ozaki-r Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_inet.h"
@@ -819,18 +819,18 @@
                         * context.  However, we keep it just for safety.
                         */
                        s = splsoftnet();
-                       dr = defrouter_lookup(in6, ln->lle_tbl->llt_ifp);
+                       dr = nd6_defrouter_lookup(in6, ln->lle_tbl->llt_ifp);
                        if (dr)
-                               defrtrlist_del(dr, NULL);
+                               nd6_defrtrlist_del(dr, NULL);
                        else if (!ip6_forwarding) {



Home | Main Index | Thread Index | Old Index
diff -r 730625e73968 -r db94dc897d1d sys/netinet6/in6.c
--- a/sys/netinet6/in6.c        Sun Dec 11 07:37:53 2016 +0000
+++ b/sys/netinet6/in6.c        Sun Dec 11 07:38:50 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: in6.c,v 1.222 2016/11/18 06:50:04 knakahara Exp $      */
+/*     $NetBSD: in6.c,v 1.223 2016/12/11 07:38:50 ozaki-r Exp $        */
 /*     $KAME: in6.c,v 1.198 2001/07/18 09:12:38 itojun Exp $   */
 
 /*
@@ -62,7 +62,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: in6.c,v 1.222 2016/11/18 06:50:04 knakahara Exp $");
+__KERNEL_RCSID(0, "$NetBSD: in6.c,v 1.223 2016/12/11 07:38:50 ozaki-r Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_inet.h"
@@ -722,7 +722,7 @@
                in6_purgeaddr(&ia->ia_ifa);
                ia = NULL;
                if (pr && pr->ndpr_refcnt == 0)
-                       prelist_remove(pr);
+                       nd6_prelist_remove(pr);
                run_hooks = true;
                break;
        }
@@ -1390,11 +1390,11 @@
 
        /*
         * Also, if the address being removed is autoconf'ed, call
         * pfxlist_onlink_check() since the release might affect the status of
         * other (detached) addresses.
         */
        if ((ia->ia6_flags & IN6_IFF_AUTOCONF) != 0)
-               pfxlist_onlink_check();
+               nd6_pfxlist_onlink_check();
 
        IN6_ADDRLIST_ENTRY_DESTROY(ia);
 
@@ -2149,7 +2149,7 @@
        curlwp_bindx(bound);
 
        /* Restore any detached prefixes */
-       pfxlist_onlink_check();
+       nd6_pfxlist_onlink_check();
 }
 
 void
@@ -2176,7 +2176,7 @@
        int s, bound;
 
        /* Any prefixes on this interface should be detached as well */
-       pfxlist_onlink_check();
+       nd6_pfxlist_onlink_check();
 
        bound = curlwp_bind();
        s = pserialize_read_enter();
@@ -1390,11 +1390,11 @@
        /*
         * Also, if the address being removed is autoconf'ed, call
-        * pfxlist_onlink_check() since the release might affect the status of
+        * nd6_pfxlist_onlink_check() since the release might affect the status of
         * other (detached) addresses.
         */
diff -r 730625e73968 -r db94dc897d1d sys/netinet6/nd6.c
--- a/sys/netinet6/nd6.c        Sun Dec 11 07:37:53 2016 +0000
+++ b/sys/netinet6/nd6.c        Sun Dec 11 07:38:50 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: nd6.c,v 1.212 2016/12/11 07:37:53 ozaki-r Exp $        */
+/*     $NetBSD: nd6.c,v 1.213 2016/12/11 07:38:50 ozaki-r Exp $        */
 /*     $KAME: nd6.c,v 1.279 2002/06/08 11:16:51 itojun Exp $   */
 
 /*
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: nd6.c,v 1.212 2016/12/11 07:37:53 ozaki-r Exp $");
+__KERNEL_RCSID(0, "$NetBSD: nd6.c,v 1.213 2016/12/11 07:38:50 ozaki-r Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_net_mpsafe.h"
@@ -595,7 +595,7 @@
        
        TAILQ_FOREACH_SAFE(dr, &nd_defrouter, dr_entry, next_dr) {
                if (dr->expire && dr->expire < time_uptime) {
-                       defrtrlist_del(dr, NULL);
+                       nd6_defrtrlist_del(dr, NULL);
                }
        }
 
@@ -706,7 +706,7 @@
                         * separate.  NEVER perform in6_purgeaddr here.
                         */
 
-                       prelist_remove(pr);
+                       nd6_prelist_remove(pr);
                }
        }
 
@@ -844,7 +844,7 @@
 
                if (dr->ifp == ifp) {
                        KASSERT(ext != NULL);
-                       defrtrlist_del(dr, ext);
+                       nd6_defrtrlist_del(dr, ext);
                }
        }
 
@@ -854,7 +854,7 @@
 
                if (dr->ifp == ifp) {
                        KASSERT(ext != NULL);
-                       defrtrlist_del(dr, ext);
+                       nd6_defrtrlist_del(dr, ext);
                }
        }
 
@@ -876,7 +876,7 @@
                         * by itself.
                         * (jinmei%kame.net@localhost 20010129)
                         */
-                       prelist_remove(pr);
+                       nd6_prelist_remove(pr);
                }
        }
 
@@ -889,7 +889,7 @@
                struct nd_ifinfo *ndi = ND_IFINFO(ifp);
                if (ndi && nd6_accepts_rtadv(ndi)) {
                        /* refresh default router list */
-                       defrouter_select();
+                       nd6_defrouter_select();
                }
        }
 
@@ -1168,7 +1168,7 @@
        if (!ip6_forwarding) {
                int s;
                s = splsoftnet();
-               dr = defrouter_lookup(in6, ifp);
+               dr = nd6_defrouter_lookup(in6, ifp);
 
                if (dr != NULL && dr->expire &&
                    ln->ln_state == ND6_LLINFO_STALE && gc) {
@@ -1196,20 +1196,20 @@
 
                if (ln->ln_router || dr) {
                        /*
                         * We need to unlock to avoid a LOR with rt6_flush()
                         * with the rnh and for the calls to
                         * pfxlist_onlink_check() and defrouter_select() in the
                         * block further down for calls into nd6_lookup().
                         * We still hold a ref.
                         */
                        LLE_WUNLOCK(ln);
 
                        /*
                         * rt6_flush must be called whether or not the neighbor
                         * is in the Default Router List.
                         * See a corresponding comment in nd6_na_input().
                         */
-                       rt6_flush(in6, ifp);
+                       nd6_rt_flush(in6, ifp);
                }
 
                if (dr) {
@@ -1229,17 +1229,17 @@
                        ln->ln_state = ND6_LLINFO_INCOMPLETE;
 
                        /*
                         * Since defrouter_select() does not affect the
                         * on-link determination and MIP6 needs the check
                         * before the default router selection, we perform
                         * the check now.
                         */
-                       pfxlist_onlink_check();
+                       nd6_pfxlist_onlink_check();
 
                        /*
                         * refresh default router list
                         */
-                       defrouter_select();
+                       nd6_defrouter_select();
                }
 
 #ifdef __FreeBSD__
@@ -1845,8 +1845,8 @@
 #undef ND
        case SIOCSNDFLUSH_IN6:  /* XXX: the ioctl name is confusing... */
                /* sync kernel routing table with the default router list */
-               defrouter_reset();
-               defrouter_select();
+               nd6_defrouter_reset();
+               nd6_defrouter_select();
                break;
        case SIOCSPFXFLUSH_IN6:
        {
@@ -1880,7 +1880,7 @@
                                }
                        }
                        pserialize_read_exit(_s);
-                       prelist_remove(pfx);
+                       nd6_prelist_remove(pfx);
                }
                splx(s);
                break;
@@ -1891,11 +1891,11 @@
                struct nd_defrouter *drtr, *next;
 
                s = splsoftnet();
-               defrouter_reset();
+               nd6_defrouter_reset();
                TAILQ_FOREACH_SAFE(drtr, &nd_defrouter, dr_entry, next) {
-                       defrtrlist_del(drtr, NULL);
+                       nd6_defrtrlist_del(drtr, NULL);
                }
-               defrouter_select();
+               nd6_defrouter_select();
                splx(s);
                break;
        }
@@ -2172,17 +2172,17 @@
         * Question: can we restrict the first condition to the "is_newentry"
         * case?
         * XXX: when we hear an RA from a new router with the link-layer
         * address option, defrouter_select() is called twice, since
         * defrtrlist_update called the function as well.  However, I believe
         * we can compromise the overhead, since it only happens the first
         * time.
         * XXX: although defrouter_select() should not have a bad effect
         * for those are not autoconfigured hosts, we explicitly avoid such
         * cases for safety.
         */
        if (do_update && router && !ip6_forwarding &&
            nd6_accepts_rtadv(ndi))
-               defrouter_select();
+               nd6_defrouter_select();
 }
 
 static void
@@ -1196,20 +1196,20 @@
                if (ln->ln_router || dr) {
                        /*
-                        * We need to unlock to avoid a LOR with rt6_flush()
+                        * We need to unlock to avoid a LOR with nd6_rt_flush()
                         * with the rnh and for the calls to
@@ -1196,20 +1196,20 @@
                         * with the rnh and for the calls to
-                        * pfxlist_onlink_check() and defrouter_select() in the
+                        * nd6_pfxlist_onlink_check() and nd6_defrouter_select() in the
                         * block further down for calls into nd6_lookup().
                         * We still hold a ref.
@@ -1196,20 +1196,20 @@
 
                        /*
-                        * rt6_flush must be called whether or not the neighbor
+                        * nd6_rt_flush must be called whether or not the neighbor
                         * is in the Default Router List.
                         * See a corresponding comment in nd6_na_input().
@@ -1229,17 +1229,17 @@
 
                        /*
-                        * Since defrouter_select() does not affect the
+                        * Since nd6_defrouter_select() does not affect the
                         * on-link determination and MIP6 needs the check
                         * before the default router selection, we perform
@@ -2172,17 +2172,17 @@
         * case?
         * XXX: when we hear an RA from a new router with the link-layer
-        * address option, defrouter_select() is called twice, since
+        * address option, nd6_defrouter_select() is called twice, since
         * defrtrlist_update called the function as well.  However, I believe
         * we can compromise the overhead, since it only happens the first
@@ -2172,17 +2172,17 @@
         * we can compromise the overhead, since it only happens the first
         * time.
-        * XXX: although defrouter_select() should not have a bad effect
+        * XXX: although nd6_defrouter_select() should not have a bad effect
         * for those are not autoconfigured hosts, we explicitly avoid such
         * cases for safety.